pub(crate) async fn delete_catalogs(store: &ObjectStore, region_id: RegionId)Expand description
Best-effort removal of both catalogs when dropping a region.
pub(crate) async fn delete_catalogs(store: &ObjectStore, region_id: RegionId)Best-effort removal of both catalogs when dropping a region.